Getting Started
===============

This section contains a variety of tutorials that should help get you started
with the Axelrod library.

Contents:

.. toctree::
   :maxdepth: 2

   getting_started.rst
   payoff_matrix.rst
   interactions.rst
   visualising_results.rst
   noisy_tournaments.rst
   ecological_variant.rst
   command_line.rst
